powered by
Static local variables are initialized once,
Maintainer: Neal Fultz <[email protected]>
This section should provide a more detailed overview of how to use the package, including the most important functions.
static